import {t} from "@lingui/macro";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {ButtonField} from "@rx-suite/ui";
import {LabLayoutComponentStore} from "../../stores/LabLayoutComponentStore";
import {LayoutEditViewRenderer} from "../../stores/object/LayoutEditViewRenderer";
import MemoryIcon from "@material-ui/icons/Memory";

export type AddStatusLegendButtonProps = {
    renderer: LayoutEditViewRenderer;
};

export const AddStatusLegendButton: React.FunctionComponent<AddStatusLegendButtonProps> = observer(({renderer}) => {

    const statusLegendModel = (() => {

        if (!renderer.layout) {
            return null;
        }

        const statusLegendComponent = renderer.layout.components.find((m) => m.component_type === 'status_legend');

        if (statusLegendComponent) {
            return statusLegendComponent;
        }

        const c = LabLayoutComponentStore.createModel();
        c.name = 'Status Legend';
        c.component_type = 'status_legend';
        c.width = 320;
        c.height = 100;
        c.z_index = 100; // this is an overlay
        c.options = JSON.stringify({
            show: false
        });
        renderer.layout.components.push(c);
        return c;

    })();

    const statusLegendShow = (() => {

        if (!statusLegendModel) {
            return false;
        }

        const options = statusLegendModel.viewModel.options;

        if (options == null) {
            return false;
        }

        const optionsJson = JSON.parse(options);

        return !!optionsJson.show;

    })();

    const handleToggleStatusPanel = React.useCallback(() => {

        if (!statusLegendModel) {
            return;
        }

        // show/hide is editing the component, select it
        renderer.setSelectedComponent(statusLegendModel);

        const newShow = !statusLegendShow;

        statusLegendModel.viewModel.options = JSON.stringify({
            show: newShow
        });

        // component is hidden, unselect it
        if (!newShow) {
            renderer.setSelectedComponent(undefined);
        }

    }, [renderer, statusLegendModel, statusLegendShow]);

    return <ButtonField
        startIcon={<MemoryIcon/>}
        text={statusLegendShow ? t`Hide Legend` : t`Show Legend`}
        variant={statusLegendShow ? 'outlined' : 'contained'}
        onClick={handleToggleStatusPanel}
    />;
});