import {dataStorePermission, RouteDefinition} from "@rx-suite/ui";
import {DashboardComponentsBreadModel} from './pages/dashboard_components/DashboardComponentsBreadModel';
import {DashboardBreadModel} from './pages/dashboards/DashboardBreadModel';
import {DashboardGroupSlideshow} from './pages/dashboard_groups/DashboardGroupSlideshow';
import {
    CollectionsBookmark,
    CollectionsBookmarkTwoTone,
    Dashboard,
    DashboardTwoTone,
    MultilineChart,
    Settings,
    Slideshow,
    ViewModule
} from '@material-ui/icons';
import {t} from "@lingui/macro";
import {DashboardComponentStore} from './stores/DashboardComponentStore';
import {DashboardGroupModel, DashboardGroupStore} from './stores/DashboardGroupStore';
import {DashboardStore} from "./stores/DashboardStore";
import {DashboardGroupBreadModel} from "./pages/dashboard_groups/DashboardGroupBreadModel";
import {computedFn} from "mobx-utils";
import {LabLayoutStore} from "./stores/LabLayoutStore";
import {LabLayoutBreadModel} from "./pages/lab_layouts/LabLayoutBreadModel";
import {DashboardTargetModel} from "./stores/DashboardTargetStore";
import {Redirect} from "react-router-dom";

export const getRoutes = computedFn((dashboardTargets: DashboardTargetModel[]) => {
    const rootRoute: RouteDefinition[] = [
        {
            label: '',
            to: "/",
            exact: true,
            Component: Redirect,
            props: {
                to: '/slideshow'
            }
        },
        {
            label: t`Settings`,
            to: "",
            exact: false,
            Icon: Settings,
            children: [
                {
                    label: t`Components`,
                    to: "/dashboard_components",
                    help: t`A dashboard component is a set of data that refreshes itself periodically.  A component is generally a single chart or table.`,
                    exact: false,
                    permission: dataStorePermission(DashboardComponentStore),
                    Component: DashboardComponentsBreadModel,
                    Icon: MultilineChart
                },
                {
                    label: t`Dashboards`,
                    to: "/dashboards",
                    help: t`A dashboard is a grid of dashboard components.`,
                    exact: false,
                    permission: dataStorePermission(DashboardStore),
                    Component: DashboardBreadModel,
                    Icon: Dashboard
                },
                {
                    label: t`Dashboard Groups`,
                    to: "/dashboard_groups",
                    help: t`A dashboard group is a list of dashboards that are displayed in a cycle.`,
                    exact: false,
                    permission: dataStorePermission(DashboardGroupStore),
                    Component: DashboardGroupBreadModel,
                    Icon: CollectionsBookmark
                },
                {
                    label: t`Lab Layout`,
                    to: "/lab_layouts",
                    exact: false,
                    permission: dataStorePermission(LabLayoutStore),
                    Component: LabLayoutBreadModel,
                    Icon: ViewModule,
                    shouldMount: () => {
                        return dashboardTargets.find(t => t.dashboard_id === 'lab_status') !== undefined
                    }
                }
            ]
        }
    ];

    return [
        {
            label: t`View`,
            to: "/slideshow",
            exact: true,
            Icon: Slideshow,
            Component: DashboardGroupSlideshow,
            children: (DashboardGroupStore.models as DashboardGroupModel[]).filter(g => !g.isNew).map(group => ({
                label: group.name as string,
                to: `/${group.getId()}`,
                exact: true,
                Component: DashboardGroupSlideshow,
                Icon: CollectionsBookmarkTwoTone,
                props: {groupId: group.getId()},
                children: group.members!.map(member => ({
                    label: ((member.dashboard || {}).name || 'Dashboard'),
                    to: `/${member.getId()}`,
                    exact: true,
                    Component: DashboardGroupSlideshow,
                    Icon: DashboardTwoTone,
                    props: {groupId: group.getId(), initialMemberId: member.getId()}
                }))
            }))
        }
    ].concat(rootRoute);
});
